Learn R Programming

readrba (version 0.1.12)

check_if_rba_ts: Perform a minimal check to see if a dataframe is formatted in a standard way for an RBA time series spreadsheet. Checks to see if various strings are present in the first column of the DF.

Description

Perform a minimal check to see if a dataframe is formatted in a standard way for an RBA time series spreadsheet. Checks to see if various strings are present in the first column of the DF.

Usage

check_if_rba_ts(df)

Value

Logical; TRUE if df contains the expected strings in first col; FALSE if not.

Arguments

df

A data frame