rename_excel: This function checks to see if an Excel file's extension matches its
signature; if it does not, the file will be renamed so that the file
extension is equal to the signature
Description
This function checks to see if an Excel file's extension matches its
signature; if it does not, the file will be renamed so that the file
extension is equal to the signature