Perform a minimal check to see if a dataframe is formatted in a standard way for an RBA time series spreadsheet. Checks to see if various strings are present in the first column of the DF.
check_if_rba_ts(df)Logical; TRUE if df contains the expected strings in first col;
FALSE if not.
A data frame